#!/usr/bin/env Rscript
#
#  This file is part of ProfileView.
#
#  ProfileView is free software: you can redistribute it and/or modify
#  it under the terms of the CeCILL 2.1 Licence
#
#  ProfileView is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  You should have received a copy of the Licence CeCILL 2.1 along
#  with ProfileView. If not, see <https://cecill.info/>.
#


library(ape)

args = commandArgs(trailingOnly=TRUE)
if (length(args)==0) {
    stop("at least one argument must be supplied")
} else if (length(args)==1) {
    args[2] <- .99
    args[3] <- ''
} else if (length(args)==2) {
    args[3] <- ''
}

feat <- read.table( args[1], row.names=1, header=TRUE, sep="\t", na.strings=c("") )
pc <- prcomp(feat[,c(-1,-2)], scale=T)

eigs <- pc$sdev^2
cumvar = cumsum(eigs)/sum(eigs) # cumulative explaned variance of PCs
pc_i = min( c(length(cumvar),which(cumvar >= as.double(args[2])) ) ) # get the PC that allows to explain at least the 99% of the variance

d <- dist(pc$x[,1:pc_i])
hc <- hclust(d,method="ward.D2")

my_tree <- as.phylo(hc)
if ( args[3] == '' ) {
    write.tree(phy=my_tree,file=stdout())
} else {
    write.tree(phy=my_tree,file=args[3])
}

